package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.reservRecord.ReservRecord;

import java.util.List;


/**
 * 预约记录Mapper接口
 * 
 * @author boman
 * @date 2025-02-19
 */
public interface ReservRecordMapper 
{
    /**
     * 查询预约记录
     * 
     * @param reservRecordId 预约记录主键
     * @return 预约记录
     */
    public ReservRecord selectReservRecordByReservRecordId(Long reservRecordId);

    /**
     * 查询预约记录列表
     * 
     * @param reservRecord 预约记录
     * @return 预约记录集合
     */
    public List<ReservRecord> selectReservRecordList(ReservRecord reservRecord);

    /**
     * 新增预约记录
     * 
     * @param reservRecord 预约记录
     * @return 结果
     */
    public int insertReservRecord(ReservRecord reservRecord);

    /**
     * 修改预约记录
     * 
     * @param reservRecord 预约记录
     * @return 结果
     */
    public int updateReservRecord(ReservRecord reservRecord);

    /**
     * 删除预约记录
     * 
     * @param reservRecordId 预约记录主键
     * @return 结果
     */
    public int deleteReservRecordByReservRecordId(Long reservRecordId);

    /**
     * 批量删除预约记录
     * 
     * @param reservRecordIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteReservRecordByReservRecordIds(Long[] reservRecordIds);
}
